# MaterialClassificationSummaryResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**date_created** | **datetime** |  | 
**sample_date** | **datetime** |  | 
**material_classification_reference_number** | **str** |  | 
**street** | **str** |  | 
**town** | **str** |  | 
**area** | **str** |  | 
**usrn** | **float** |  | 
**material_classification_classification** | [**MaterialClassificationClassification**](MaterialClassificationClassification.md) |  | 
**hazardous_material_types** | [**list[HazardousMaterialType]**](HazardousMaterialType.md) |  | [optional] 
**hazardous_material_type_other_description** | **str** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

